@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionreplace.h"
 #include "editor/sieveeditorutil.h"
@@ -40,14 +27,14 @@ SieveActionReplace::SieveActionReplace(SieveEditorGraphicalModeWidget *sieveGrap
 QWidget *SieveActionReplace::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QGridLayout *grid = new QGridLayout;
-    grid->setContentsMargins(0, 0, 0, 0);
+    auto *grid = new QGridLayout;
+    grid->setContentsMargins({});
     w->setLayout(grid);
 
     QLabel *lab = new QLabel(i18n("Subject:"));
     grid->addWidget(lab, 0, 0);
 
-    QLineEdit *subject = new QLineEdit;
+    auto *subject = new QLineEdit;
     subject->setObjectName(QStringLiteral("subject"));
     connect(subject, &QLineEdit::textChanged, this, &SieveActionReplace::valueChanged);
     grid->addWidget(subject, 0, 1);
@@ -63,7 +50,7 @@ QWidget *SieveActionReplace::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("text:"));
     grid->addWidget(lab, 2, 0);
 
-    MultiLineEdit *text = new MultiLineEdit;
+    auto *text = new MultiLineEdit;
     text->setObjectName(QStringLiteral("text"));
     connect(text, &MultiLineEdit::textChanged, this, &SieveActionReplace::valueChanged);
     grid->addWidget(text, 2, 1);
@@ -71,25 +58,25 @@ QWidget *SieveActionReplace::createParamWidget(QWidget *parent) const
     return w;
 }
 
-bool SieveActionReplace::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
+void SieveActionReplace::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, QString &error)
 {
     while (element.readNextStartElement()) {
         const QStringRef tagName = element.name();
         if (tagName == QLatin1String("str")) {
-            MultiLineEdit *edit = w->findChild<MultiLineEdit *>(QStringLiteral("text"));
+            auto *edit = w->findChild<MultiLineEdit *>(QStringLiteral("text"));
             edit->setPlainText(element.readElementText());
         } else if (tagName == QLatin1String("tag")) {
             const QString tagValue = element.readElementText();
             if (tagValue == QLatin1String("subject")) {
                 const QString strValue = AutoCreateScriptUtil::strValue(element);
                 if (!strValue.isEmpty()) {
-                    QLineEdit *subject = w->findChild<QLineEdit *>(QStringLiteral("subject"));
+                    auto *subject = w->findChild<QLineEdit *>(QStringLiteral("subject"));
                     subject->setText(strValue);
                 }
             } else if (tagValue == QLatin1String("from")) {
                 const QString strValue = AutoCreateScriptUtil::strValue(element);
                 if (!strValue.isEmpty()) {
-                    KSieveUi::AbstractSelectEmailLineEdit *headers = w->findChild<KSieveUi::AbstractSelectEmailLineEdit *>(QStringLiteral("from"));
+                    auto *headers = w->findChild<KSieveUi::AbstractSelectEmailLineEdit *>(QStringLiteral("from"));
                     headers->setText(strValue);
                 }
             } else {
@@ -107,8 +94,6 @@ bool SieveActionReplace::setParamWidgetValue(QXmlStreamReader &element, QWidget
             qCDebug(LIBKSIEVE_LOG) << " SieveActionReplace::setParamWidgetValue unknown tagName " << tagName;
         }
     }
-
-    return true;
 }
 
 QString SieveActionReplace::code(QWidget *w) const
