@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionspamtest.h"
 #include "widgets/selectrelationalmatchtype.h"
@@ -42,8 +29,8 @@ SieveConditionSpamTest::SieveConditionSpamTest(SieveEditorGraphicalModeWidget *s
 QWidget *SieveConditionSpamTest::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QVBoxLayout *lay = new QVBoxLayout;
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto *lay = new QVBoxLayout;
+    lay->setContentsMargins({});
     w->setLayout(lay);
 
     if (mHasSpamTestPlusSupport) {
@@ -53,17 +40,17 @@ QWidget *SieveConditionSpamTest::createParamWidget(QWidget *parent) const
         lay->addWidget(percent);
     }
 
-    SelectRelationalMatchType *relation = new SelectRelationalMatchType;
+    auto *relation = new SelectRelationalMatchType;
     connect(relation, &SelectRelationalMatchType::valueChanged, this, &SieveConditionSpamTest::valueChanged);
     relation->setObjectName(QStringLiteral("relation"));
     lay->addWidget(relation);
 
-    SelectComparatorComboBox *comparator = new SelectComparatorComboBox(mSieveGraphicalModeWidget);
+    auto *comparator = new SelectComparatorComboBox(mSieveGraphicalModeWidget);
     connect(comparator, &SelectComparatorComboBox::valueChanged, this, &SieveConditionSpamTest::valueChanged);
     comparator->setObjectName(QStringLiteral("comparator"));
     lay->addWidget(comparator);
 
-    QSpinBox *spinbox = new QSpinBox;
+    auto *spinbox = new QSpinBox;
     spinbox->setMaximum(10);
     spinbox->setMinimum(0);
     spinbox->setObjectName(QStringLiteral("value"));
@@ -122,7 +109,7 @@ QString SieveConditionSpamTest::help() const
     return i18n("Sieve implementations that implement the \"spamtest\" test use an identifier of either \"spamtest\" or \"spamtestplus\" for use with the capability mechanism.");
 }
 
-bool SieveConditionSpamTest::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool /*notCondition*/, QString &error)
+void SieveConditionSpamTest::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool /*notCondition*/, QString &error)
 {
     QString commentStr;
     while (element.readNextStartElement()) {
@@ -132,20 +119,20 @@ bool SieveConditionSpamTest::setParamWidgetValue(QXmlStreamReader &element, QWid
             if (tagValue == QLatin1String("count") || tagValue == QLatin1String("value")) {
                 if (element.readNextStartElement()) {
                     if (element.name() == QLatin1String("str")) {
-                        SelectRelationalMatchType *relation = w->findChild<SelectRelationalMatchType *>(QStringLiteral("relation"));
+                        auto *relation = w->findChild<SelectRelationalMatchType *>(QStringLiteral("relation"));
                         relation->setCode(AutoCreateScriptUtil::tagValue(tagValue), element.readElementText(), name(), error);
                     }
                 }
             } else if (tagValue == QLatin1String("comparator")) {
                 if (element.readNextStartElement()) {
                     if (element.name() == QLatin1String("str")) {
-                        SelectComparatorComboBox *comparator = w->findChild<SelectComparatorComboBox *>(QStringLiteral("comparator"));
+                        auto *comparator = w->findChild<SelectComparatorComboBox *>(QStringLiteral("comparator"));
                         comparator->setCode(element.readElementText(), name(), error);
                     }
                 }
             } else if (tagValue == QLatin1String("percent")) {
                 if (mHasSpamTestPlusSupport) {
-                    QCheckBox *checkbox = w->findChild<QCheckBox *>(QStringLiteral("percent"));
+                    auto *checkbox = w->findChild<QCheckBox *>(QStringLiteral("percent"));
                     checkbox->setChecked(true);
                 } else {
                     serverDoesNotSupportFeatures(QStringLiteral("percent"), error);
@@ -156,7 +143,7 @@ bool SieveConditionSpamTest::setParamWidgetValue(QXmlStreamReader &element, QWid
                 qCDebug(LIBKSIEVE_LOG) << " SieveConditionSpamTest::setParamWidgetValue unknown tagvalue " << tagValue;
             }
         } else if (tagName == QLatin1String("str")) {
-            QSpinBox *spinbox = w->findChild<QSpinBox *>(QStringLiteral("value"));
+            auto *spinbox = w->findChild<QSpinBox *>(QStringLiteral("value"));
             spinbox->setValue(element.readElementText().toInt());
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
@@ -171,7 +158,6 @@ bool SieveConditionSpamTest::setParamWidgetValue(QXmlStreamReader &element, QWid
     if (!commentStr.isEmpty()) {
         setComment(commentStr);
     }
-    return true;
 }
 
 QUrl SieveConditionSpamTest::href() const
