@@ -1,27 +1,14 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef SIEVECONDITIONWIDGETLISTER_H
 #define SIEVECONDITIONWIDGETLISTER_H
 
 #include <Libkdepim/KWidgetLister>
-
+#include <QVector>
 class QPushButton;
 class QGridLayout;
 class QXmlStreamReader;
@@ -57,14 +44,14 @@ private:
     void slotAddComment();
     void initWidget();
     void setFilterCondition(QWidget *widget);
-    QList<KSieveUi::SieveCondition *> mConditionList;
+    QVector<KSieveUi::SieveCondition *> mConditionList;
     QPushButton *mAdd = nullptr;
     QPushButton *mRemove = nullptr;
     QComboBox *mComboBox = nullptr;
     QGridLayout *mLayout = nullptr;
     SieveHelpButton *mHelpButton = nullptr;
     QToolButton *mCommentButton = nullptr;
-    SieveEditorGraphicalModeWidget *mSieveGraphicalModeWidget = nullptr;
+    SieveEditorGraphicalModeWidget *const mSieveGraphicalModeWidget;
 };
 
 class SieveConditionWidgetLister : public KPIM::KWidgetLister
